@@ -31,6 +31,15 @@ def get_credentials():
     return scoped_credentials
 
 
+def set_credentials_secret_path(project="emart-datafabric", mount_point="datafabric", path="gcp/emart-datafabric/datafabric"):
+    global PROJECT_ID
+    PROJECT_ID = project
+    global CREDENTIALS_SECRET_MOUNT_POINT
+    CREDENTIALS_SECRET_MOUNT_POINT = mount_point
+    global CREDENTIALS_SECRET_PATH
+    CREDENTIALS_SECRET_PATH = path
+
+
 def set_default_credentials():
     import os
     from pydatafabric.vault_utils import get_secrets
