@@ -307,7 +307,7 @@ def slack_send(
         raise Exception(r.json())
 
 
-def send_email(subject, text, send_from, send_to, attachment=None):
+def send_email(subject, text, send_from, send_to, attachment=None, file_format=None):
     """
     :param str attachment: Attachment to send as .txt file with email
     """
@@ -328,8 +328,11 @@ def send_email(subject, text, send_from, send_to, attachment=None):
     msg.attach(MIMEText(text))
 
     if attachment:
+        file_format = "txt"
+        if file_format:
+            file_format = file_format
         part = MIMEApplication(attachment, NAME=subject)
-        part.add_header("Content-Disposition", f"attachment; filename={subject}.txt")
+        part.add_header("Content-Disposition", f"attachment; filename={subject}.{file_format}")
         msg.attach(part)
 
     with smtplib.SMTP(host=host, port=port, local_hostname=ehlo) as smtp:
@@ -380,16 +383,12 @@ def _write_to_parquet(pandas_df, hdfs_path):
         hdfs_conn.close()
 
 
-def _write_df(
-    pandas_df, schema_name, table_name, hdfs_path, engine, cursor, tmp_table_name
-):
+def _write_df(pandas_df, schema_name, table_name, hdfs_path, engine, cursor, tmp_table_name):
     import sqlalchemy.exc
 
     cursor.execute(f"drop table if exists {schema_name}.{tmp_table_name}")
     try:
-        pandas_df.to_sql(
-            tmp_table_name, engine, schema=schema_name, if_exists="replace", index=False
-        )
+        pandas_df.to_sql(tmp_table_name, engine, schema=schema_name, if_exists="replace", index=False)
     except sqlalchemy.exc.ProgrammingError:
         # Hive bulk insert issue:
         # https://github.com/dropbox/PyHive/issues/343
@@ -404,9 +403,7 @@ def _write_df(
         )
         cursor.execute(f"show create table {schema_name}.{table_name}")
         result = cursor.fetchall()
-        managed_hdfs_path = list(
-            filter(lambda row: row[0].strip().find("hdfs://") == 1, result)
-        )[0][0].strip()[1:-1]
+        managed_hdfs_path = list(filter(lambda row: row[0].strip().find("hdfs://") == 1, result))[0][0].strip()[1:-1]
         _write_to_parquet(pandas_df, managed_hdfs_path)
     else:
         cursor.execute(
@@ -447,9 +444,7 @@ def write_df_to_hive(pandas_df, schema_name, table_name, hdfs_path=None):
 
     import hashlib
 
-    tmp_table_name = hashlib.sha1(
-        str(f"{schema_name}.{table_name}").encode("utf-8")
-    ).hexdigest()
+    tmp_table_name = hashlib.sha1(str(f"{schema_name}.{table_name}").encode("utf-8")).hexdigest()
 
     try:
         _write_df(
